gui — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- action_steps »

# gui

Various `ActionStep` subclasses that manipulate the GUI of the application.

class `camelot.view.action_steps.gui.` `OpenFormView`(objects, admin)

  Open the form view for a list of objects, in a non blocking way :param objects: the list of objects to display in the form view :param admin: the admin class to use to display the form

class `camelot.view.action_steps.gui.` `Refresh`

  Refresh all the open screens on the desktop, this will reload queries from the database

class `camelot.view.action_steps.gui.` `ShowChart`(chart)

  Show a full screen chart.

  Parameters: | chart – a `camelot.core.container.FigureContainer` or `camelot.core.container.AxesContainer`

class `camelot.view.action_steps.gui.` `ShowPixmap`(pixmap)

  Show a full screen pixmap

  Parameters: | pixmap – a `camelot.view.art.Pixmap` object

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- action_steps »

Comments
blog comments powered by Disqus